@@ -2,7 +2,7 @@ package App::plenv;
 use strict;
 use warnings;
 use 5.008002;
-our $VERSION = '1.4.10';
+our $VERSION = '1.4.11';
 
 
 
@@ -19,7 +19,25 @@ See L<plenv>
 
 =head1 AUTHOR
 
-Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ GMAIL COME<gt>
+Tokuhiro Matsuno E<lt>tokuhirom@gmail.comE<gt>
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item Masato Ikeda E<lt>masato.ikeda@gmail.comE<gt>
+
+=item Nishibayashi Takuji E<lt>takuji31@gmail.comE<gt>
+
+=item Syohei YOSHIDA E<lt>syohex@gmail.comE<gt>
+
+=item xaicron E<lt>xaicron@gmail.comE<gt>
+
+=item moznion E<lt>moznion@gmail.comE<gt>
+
+=item ks E<lt>ks-for-git@live.jpE<gt>
+
+=back
 
 =head1 SEE ALSO
 
